@@ -528,7 +528,7 @@ trls.influence <- function (object)
     nr <- length(object$z)
     nc <- length(object$beta)
     X <- matrix(object$f, nrow = nr, ncol = nc)
-    hii <- hat(X, FALSE)
+    hii <- stats::hat(X, FALSE)
     s <- sqrt(deviance(object)/df.residual.trls(object))
     r <- residuals(object)
     stresid <- r/(s * sqrt(1 - hii))
